import { createStyles } from '@udecode/plate-styled-components';
import _styled, { css } from 'styled-components';
import 'react';
import { jsx } from 'react/jsx-runtime';
import { ELEMENT_CODE_BLOCK, insertEmptyCodeBlock } from '@udecode/plate-code-block';
import { getPreventDefaultHandler } from '@udecode/plate-common';
import { useStoreEditorState, useEventEditorId, getPlatePluginType } from '@udecode/plate-core';
import { ToolbarElement } from '@udecode/plate-toolbar';

const getCodeBlockElementStyles = props => createStyles({
  prefixClassNames: 'CodeBlockElement',
  ...props
}, {
  root: [{
    "whiteSpace": "pre-wrap",
    "paddingTop": "0.75rem",
    "paddingBottom": "0.75rem",
    "paddingLeft": "1rem",
    "paddingRight": "1rem"
  }, css(["font-size:16px;font-family:SFMono-Regular,Consolas,Monaco,'Liberation Mono',Menlo,Courier,monospace;tab-size:2;line-height:normal;border-radius:3px;background-color:rgb(247,246,243);"])]
});

const CodeBlockElement = props => {
  const {
    attributes,
    children,
    nodeProps
  } = props;
  const {
    root
  } = getCodeBlockElementStyles(props);
  return /*#__PURE__*/jsx(_StyledPre, { ...attributes,
    className: root.className,
    ...nodeProps,
    $_css: root.css,
    children: /*#__PURE__*/jsx("code", {
      children: children
    })
  });
};

var _StyledPre = _styled("pre").withConfig({
  displayName: "CodeBlockElement___StyledPre",
  componentId: "sc-edret1-0"
})(["", ""], p => p.$_css);

const getCodeLineElementStyles = props => createStyles({
  prefixClassNames: 'CodeLineElement',
  ...props
}, {
  root: [{}]
});

const CodeLineElement = props => {
  const {
    attributes,
    children
  } = props;
  const {
    root
  } = getCodeLineElementStyles(props);
  return /*#__PURE__*/jsx(_StyledDiv, { ...attributes,
    className: root.className,
    $_css: root.css,
    children: children
  });
};

var _StyledDiv = _styled("div").withConfig({
  displayName: "CodeLineElement___StyledDiv",
  componentId: "sc-11fh9za-0"
})(["", ""], p => p.$_css);

const ToolbarCodeBlock = ({
  options,
  ...props
}) => {
  const editor = useStoreEditorState(useEventEditorId('focus'));
  return /*#__PURE__*/jsx(ToolbarElement, {
    type: getPlatePluginType(editor, ELEMENT_CODE_BLOCK),
    onMouseDown: editor && getPreventDefaultHandler(insertEmptyCodeBlock, editor, {
      insertNodesOptions: {
        select: true
      },
      ...options
    }),
    ...props
  });
};

export { CodeBlockElement, CodeLineElement, ToolbarCodeBlock, getCodeBlockElementStyles, getCodeLineElementStyles };
//# sourceMappingURL=index.es.js.map
